# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This file is auto generated by the elixir code generator program.
# Do not edit this file manually.

defmodule GoogleApi.YouTube.V3.Model.PlaylistSnippet do
  @moduledoc """
  Basic details about a playlist, including title, description and thumbnails.

  ## Attributes

  *   `channelId` (*type:* `String.t`, *default:* `nil`) - The ID that YouTube uses to uniquely identify the channel that published the playlist.
  *   `channelTitle` (*type:* `String.t`, *default:* `nil`) - The channel title of the channel that the video belongs to.
  *   `defaultLanguage` (*type:* `String.t`, *default:* `nil`) - The language of the playlist's default title and description.
  *   `description` (*type:* `String.t`, *default:* `nil`) - The playlist's description.
  *   `localized` (*type:* `GoogleApi.YouTube.V3.Model.PlaylistLocalization.t`, *default:* `nil`) - Localized title and description, read-only.
  *   `publishedAt` (*type:* `DateTime.t`, *default:* `nil`) - The date and time that the playlist was created.
  *   `tags` (*type:* `list(String.t)`, *default:* `nil`) - Keyword tags associated with the playlist.
  *   `thumbnailVideoId` (*type:* `String.t`, *default:* `nil`) - Note: if the playlist has a custom thumbnail, this field will not be populated. The video id selected by the user that will be used as the thumbnail of this playlist. This field defaults to the first publicly viewable video in the playlist, if: 1. The user has never selected a video to be the thumbnail of the playlist. 2. The user selects a video to be the thumbnail, and then removes that video from the playlist. 3. The user selects a non-owned video to be the thumbnail, but that video becomes private, or gets deleted.
  *   `thumbnails` (*type:* `GoogleApi.YouTube.V3.Model.ThumbnailDetails.t`, *default:* `nil`) - A map of thumbnail images associated with the playlist. For each object in the map, the key is the name of the thumbnail image, and the value is an object that contains other information about the thumbnail.
  *   `title` (*type:* `String.t`, *default:* `nil`) - The playlist's title.
  """

  use GoogleApi.Gax.ModelBase

  @type t :: %__MODULE__{
          :channelId => String.t() | nil,
          :channelTitle => String.t() | nil,
          :defaultLanguage => String.t() | nil,
          :description => String.t() | nil,
          :localized => GoogleApi.YouTube.V3.Model.PlaylistLocalization.t() | nil,
          :publishedAt => DateTime.t() | nil,
          :tags => list(String.t()) | nil,
          :thumbnailVideoId => String.t() | nil,
          :thumbnails => GoogleApi.YouTube.V3.Model.ThumbnailDetails.t() | nil,
          :title => String.t() | nil
        }

  field(:channelId)
  field(:channelTitle)
  field(:defaultLanguage)
  field(:description)
  field(:localized, as: GoogleApi.YouTube.V3.Model.PlaylistLocalization)
  field(:publishedAt, as: DateTime)
  field(:tags, type: :list)
  field(:thumbnailVideoId)
  field(:thumbnails, as: GoogleApi.YouTube.V3.Model.ThumbnailDetails)
  field(:title)
end

defimpl Poison.Decoder, for: GoogleApi.YouTube.V3.Model.PlaylistSnippet do
  def decode(value, options) do
    GoogleApi.YouTube.V3.Model.PlaylistSnippet.decode(value, options)
  end
end

defimpl Poison.Encoder, for: GoogleApi.YouTube.V3.Model.PlaylistSnippet do
  def encode(value, options) do
    GoogleApi.Gax.ModelBase.encode(value, options)
  end
end
